Report class

Constructors

Report(dynamic error, dynamic stackTrace, DateTime dateTime, Map<String, dynamic> deviceParameters, Map<String, dynamic> applicationParameters, Map<String, dynamic> customParameters, FlutterErrorDetails? errorDetails, PlatformType platformType, Map screenRouters)
Creates report instance

Properties

applicationParameters → Map<String, dynamic>
Application info
final
customParameters → Map<String, dynamic>
Custom parameters passed to report
final
dateTime → DateTime
Time when it was caught
final
deviceParameters → Map<String, dynamic>
Device info
final
error → dynamic
Error that has been caught
final
errorDetails → FlutterErrorDetails?
FlutterErrorDetails data if present
final
hashCode → int
The hash code for this object.
no setterinherited
platformType → PlatformType
Type of platform used
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenRouters → Map
final
stackTrace → dynamic
Stack trace of error
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({bool enableDeviceParameters = true, bool enableApplicationParameters = true, bool enableStackTrace = true, bool enableCustomParameters = false, bool enalbeScreen = true, bool enableScreenRouters = true}) → Map<String, dynamic>
Creates json from current instance
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited